@@ -8,17 +8,14 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "cdk-lambda-layer-zip",
-    "1.0.395",
+    "2.0.2",
     __name__[0:-6],
-    "cdk-lambda-layer-zip@1.0.395.jsii.tgz",
+    "cdk-lambda-layer-zip@2.0.2.jsii.tgz",
 )
 
 __all__ = [
